.. _spkg_jupyter_server_terminals:

jupyter_server_terminals: A Jupyter Server Extension Providing Terminals
==================================================================================

Description
-----------

A Jupyter Server Extension Providing Terminals.

License
-------

Modified BSD License (also known as New or Revised or 3-Clause BSD)

Upstream Contact
----------------

https://pypi.org/project/jupyter-server-terminals/


Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_terminado`

Version Information
-------------------

package-version.txt::

    0.4.4

version_requirements.txt::

    jupyter-server-terminals


Equivalent System Packages
--------------------------

(none known)

